==> eiffelstudio-19.05.10.3187.tar: F_code/C56/es2769.c <==
/*
 * Code for class ES_KEY_SHORTCUT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "es2769.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ES_KEY_SHORTCUT}.make_with_key_combination */
void F3865_46651 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2, EIF_BOOLEAN arg3, EIF_BOOLEAN arg4)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("make_with_key_combination", 3864, Current, 0, 4, 49514);
	RTGC;
	RTHOOK(1);
	F3865_46661(Current, arg1);
	RTHOOK(2);
	if (arg2) {
		RTHOOK(3);
		F3865_46666(Current);
	}
	RTHOOK(4);
	if (arg3) {
		RTHOOK(5);
		F3865_46664(Current);
	}
	RTHOOK(6);
	if (arg4) {
		RTHOOK(7);
		F3865_46662(Current);
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {ES_KEY_SHORTCUT}.hash_code */
EIF_INTEGER_32 F3865_46653 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("hash_code", 3864, Current, 0, 0, 49516);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_0_0_0_0_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.text */
EIF_REFERENCE F3865_46655 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("text", 3864, Current, 1, 0, 49499);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(4143, 0x00).id, 4143, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F4142_50644(RTCW(Result), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_)) {
		RTHOOK(3);
		tr1 = RTMS_EX_H("Ctrl+",5,1954170411);
		F4144_50756(RTCW(Result), tr1);
	}
	RTHOOK(4);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
		RTHOOK(5);
		tr1 = RTMS_EX_H("Alt+",4,1097626667);
		F4144_50756(RTCW(Result), tr1);
	}
	RTHOOK(6);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		RTHOOK(7);
		tr1 = RTMS_EX_H("Shift+",6,1932305451);
		F4144_50756(RTCW(Result), tr1);
	}
	RTHOOK(8);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc1 = F5626_75241(RTCW(tr1));
	RTHOOK(9);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O40834[Dtype(loc1)-4141]);
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(10);
		tr1 = F4144_50792(RTCW(loc1));
		loc1 = (EIF_REFERENCE) tr1;
		RTHOOK(11);
		F4144_50798(RTCW(loc1));
	}
	RTHOOK(12);
	F4144_50757(RTCW(Result), loc1);
	RTHOOK(13);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.is_triggered */
EIF_BOOLEAN F3865_46659 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2, EIF_BOOLEAN arg3, EIF_BOOLEAN arg4)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("is_triggered", 3864, Current, 0, 4, 49503);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tb3 = (EIF_BOOLEAN) eif_builtin_ANY_is_equal (tr1, arg1);
	if (tb3) {
		tb2 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) == arg3);
	}
	if (tb2) {
		tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == arg4);
	}
	if (tb1) {
		Result = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) == arg2);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.is_equal */
EIF_BOOLEAN F3865_46660 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("is_equal", 3864, Current, 0, 1, 49504);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_2_);
	tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_1_);
	tb3 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_0_);
	Result = F3865_46659(Current, tr1, tb1, tb2, tb3);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.set_key */
void F3865_46661 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_key", 3864, Current, 0, 1, 49505);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_shift_required */
void F3865_46662 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_shift_required", 3864, Current, 0, 0, 49506);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_shift_required */
void F3865_46663 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_shift_required", 3864, Current, 0, 0, 49507);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_alt_required */
void F3865_46664 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_alt_required", 3864, Current, 0, 0, 49508);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_alt_required */
void F3865_46665 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_alt_required", 3864, Current, 0, 0, 49509);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_control_required */
void F3865_46666 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_control_required", 3864, Current, 0, 0, 49510);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_control_required */
void F3865_46667 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_control_required", 3864, Current, 0, 0, 49511);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

void EIF_Minit2769 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C56/es2769.c <==
/*
 * Code for class ES_KEY_SHORTCUT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "es2769.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ES_KEY_SHORTCUT}.make_with_key_combination */
void F3852_45409 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2, EIF_BOOLEAN arg3, EIF_BOOLEAN arg4)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("make_with_key_combination", 3851, Current, 0, 4, 47409);
	RTGC;
	RTHOOK(1);
	F3852_45419(Current, arg1);
	RTHOOK(2);
	if (arg2) {
		RTHOOK(3);
		F3852_45424(Current);
	}
	RTHOOK(4);
	if (arg3) {
		RTHOOK(5);
		F3852_45422(Current);
	}
	RTHOOK(6);
	if (arg4) {
		RTHOOK(7);
		F3852_45420(Current);
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {ES_KEY_SHORTCUT}.hash_code */
EIF_INTEGER_32 F3852_45411 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("hash_code", 3851, Current, 0, 0, 47411);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_0_0_0_0_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.text */
EIF_REFERENCE F3852_45413 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("text", 3851, Current, 1, 0, 47413);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(4029, 0x00).id, 4029, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F4027_47904(RTCW(Result), ((EIF_INTEGER_32) 0L));
	RTHOOK(2);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_)) {
		RTHOOK(3);
		tr1 = RTMS_EX_H("Ctrl+",5,1954170411);
		F4030_48052(RTCW(Result), tr1);
	}
	RTHOOK(4);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_)) {
		RTHOOK(5);
		tr1 = RTMS_EX_H("Alt+",4,1097626667);
		F4030_48052(RTCW(Result), tr1);
	}
	RTHOOK(6);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		RTHOOK(7);
		tr1 = RTMS_EX_H("Shift+",6,1932305451);
		F4030_48052(RTCW(Result), tr1);
	}
	RTHOOK(8);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc1 = F6124_82085(RTCW(tr1));
	RTHOOK(9);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O39285[Dtype(loc1)-4026]);
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(10);
		tr1 = F4030_48089(RTCW(loc1));
		loc1 = (EIF_REFERENCE) tr1;
	}
	RTHOOK(11);
	F4030_48053(RTCW(Result), loc1);
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.is_triggered */
EIF_BOOLEAN F3852_45417 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2, EIF_BOOLEAN arg3, EIF_BOOLEAN arg4)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("is_triggered", 3851, Current, 0, 4, 47398);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tb3 = (EIF_BOOLEAN) eif_builtin_ANY_is_equal__o_b (tr1, arg1);
	if (tb3) {
		tb2 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) == arg3);
	}
	if (tb2) {
		tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == arg4);
	}
	if (tb1) {
		Result = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) == arg2);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.is_equal */
EIF_BOOLEAN F3852_45418 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("is_equal", 3851, Current, 0, 1, 47399);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb1 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_2_);
	tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_1_);
	tb3 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_0_);
	Result = F3852_45417(Current, tr1, tb1, tb2, tb3);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {ES_KEY_SHORTCUT}.set_key */
void F3852_45419 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_key", 3851, Current, 0, 1, 47400);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_shift_required */
void F3852_45420 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_shift_required", 3851, Current, 0, 0, 47401);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_shift_required */
void F3852_45421 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_shift_required", 3851, Current, 0, 0, 47402);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_alt_required */
void F3852_45422 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_alt_required", 3851, Current, 0, 0, 47403);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_alt_required */
void F3852_45423 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_alt_required", 3851, Current, 0, 0, 47404);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.enable_control_required */
void F3852_45424 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("enable_control_required", 3851, Current, 0, 0, 47405);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(3);
	RTEE;
}

/* {ES_KEY_SHORTCUT}.disable_control_required */
void F3852_45425 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("disable_control_required", 3851, Current, 0, 0, 47406);
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTEE;
}

void EIF_Minit2769 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
